# fundamentals

[![](https://readthedocs.org/projects/fundamentals/badge/)](http://fundamentals.readthedocs.io/en/latest/?badge)
[![](https://cdn.jsdelivr.net/gh/thespacedoctor/fundamentals@master/coverage.svg)](https://cdn.jsdelivr.net/gh/thespacedoctor/fundamentals@master/htmlcov/index.html) 

*Some fundamental tools required by most self-respecting python-packages bundled in one place. Very opinionated project setup tools including logging, plain-text settings files and database connections*.

Documentation for fundamentals is hosted by [Read the Docs](http://fundamentals.readthedocs.org/en/stable/) (last
[stable version](http://fundamentals.readthedocs.org/en/stable/) and [latest version](http://fundamentals.readthedocs.org/en/latest/)). The code lives on [github](https://github.com/thespacedoctor/fundamentals). Please report any issues you find [here](https://github.com/thespacedoctor/fundamentals/issues).

## Features

* 



